django>=4.2
gunicorn>=21
Pillow>=10
psycopg2-binary>=2.9.10
python-dotenv>=1
werkzeug>=3.0

django-debug-toolbar>=5.0
django-extensions>=3
django-livereload-server>=0.5

## Authentication
django-allauth>=65

## API
django-cors-headers>=4
djangorestframework>=3.15

## Tasks
celery>=5
django-celery-beat>=2.7

## Tests
coverage
