[project]
name = "{{ app }}"
description = "{{ description }}"
authors = [{ name = "Your name", email = "email@example.com" }]
maintainers = [{ name = "Your name", email = "email@example.com" }]
requires-python = ">=3.8"
license = { file = "LICENSE" }
readme = "README.md"
version = "0.1.0"
keywords = []
classifiers = []
dependencies = []

[project.urls]
Homepage = "https://github.com/username/repository"
Issues = "https://github.com/username/repository/issues"
