# coding: utf-8
"""
    {{ app }}
"""
from __future__ import unicode_literals

__version__ = '{{ version }}'
__license__ = '{{ license }}'
__copyright__ = '{{ copyright }}'

VERSION = __version__

default_app_config = '{{ app }}.apps.{{ classname }}Config'
